@@ -1,9 +1,7 @@
 """
-Mikkoo
-======
 Mikkoo is a PgQ to RabbitMQ Relay
 
 Named for the rabbit in the clever rabbit and the elephant fable.
 
 """
-__version__ = '0.4.4'
+__version__ = '2.0.0'
